aws-xray-sdk-clj.core


close!clj

(close! entity)
source

set-annotation!clj

(set-annotation! entity arg-map)
source

set-exception!clj

(set-exception! entity ex)
source

set-metadata!clj

(set-metadata! entity arg-map)
source

shutdown!clj

(shutdown!)
(shutdown! recorder)
source

start!clj

(start! entity-provider arg-map)
source

trace-recorderclj

(trace-recorder consumer)
(trace-recorder consumer options)
source

with-opencljmacro

(with-open binding & body)

Evaluates body in the scope of a generated entity.

binding => [entity-sym entity-init]

Evaluates body in the scope of a generated entity.

binding => [entity-sym entity-init]
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries