Clojure only.

aws-xray-sdk-clj.promise


handlerclj

(handler entity)
source

with-opencljmacro

(with-open bindings & body)

bindings => [name init ...] Evaluates body with promesa/do and closes the bound entity from its finalizer.

bindings => [name init ...]
Evaluates body with promesa/do and closes the bound entity from its finalizer.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries