(with-open binding & body)Evaluates body in the scope of a generated entity.
binding => [entity-sym entity-init]
Evaluates body in the scope of a generated entity. binding => [entity-sym entity-init]
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |