(with-open bindings & body)bindings => [name init ...] Evaluates body with promesa/do and closes the bound entity from its finalizer.
bindings => [name init ...] Evaluates body with promesa/do and closes the bound entity from its finalizer.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |